.. _installation:

Installation
============

uv
--

.. code-block:: bash

    uv tool install elhaz

pipx
----

.. code-block:: bash
    
    pipx install elhaz

GitHub + uv
-----------

.. code-block:: bash

    git clone https://github.com/michaelthomasletts/elhaz.git
    cd elhaz
    uv tool install .
